@@ -11,7 +11,7 @@ use Scalar::Util qw( looks_like_number );
 
 use Git::Repository::Command;
 
-our $VERSION = '1.24';
+our $VERSION = '1.26';
 
 # a few simple accessors
 for my $attr (qw( git_dir work_tree options )) {
@@ -192,6 +192,7 @@ sub run {
         = Git::Repository::Command->new( ref $self ? $self : (), @cmd );
 
     # return the output or die
+    local $Carp::CarpLevel = 1;
     return $command->final_output;
 }
 
@@ -582,6 +583,9 @@ See L<Git::Repository::Plugin> about how to create a new plugin.
 
 =head1 OTHER PERL GIT WRAPPERS
 
+(This section was written in June 2010. The other Git wrappers have
+probably evolved since that time.)
+
 A number of Perl git wrappers already exist. Why create a new one?
 
 I have a lot of ideas of nice things to do with Git as a tool to
@@ -688,7 +692,7 @@ I came up with.
 
 =head1 COPYRIGHT
 
-Copyright 2010-2011 Philippe Bruhat (BooK), all rights reserved.
+Copyright 2010-2012 Philippe Bruhat (BooK), all rights reserved.
 
 =head1 LICENSE
 
